baleen

package module
v0.0.0-...-78db06c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2019 License: AGPL-3.0 Imports: 1 Imported by: 0

README

Baleen

An automated ingestion service of RSS feeds to construct a corpus for NLP research.

Build Status GoDoc Go Report Card

Documentation

Overview

Package baleen is the top level library of the baleen language ingestion service. This library provides the primary components for running the service as a long running background daemon including the main service itself, configuration and other utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Version

func Version(short bool) string

Version returns a string representation of the semantic package version number.

Types

This section is empty.

Directories

Path Synopsis
cmd
baleen command

Jump to